! ESA (C) 2000-2018 
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
!
!+
! Module: gofconstants_mod
!
! Authors:  Brendan Perry - GSFC 
!          
! Description: Define useful mathematical and physical constants
! 
! Comments: 
! Many more constants are found in ssclib, with ones needed for euler,
! jpl ephemeris calculations, etc.
! 
! $Id: module.f90,v 1.5 1998/01/13 08:39:15 gvacanti Exp $
!- 
module gofconstants_mod

  use types ! for DAL variable kind definitions: single, double, int8 etc.

  implicit none 

  public

  character(len=80), parameter :: &
       comline1 = &
       "This file was produced using the XMM-ESAS software written by",&
       comline2 = "S.L. Snowden, and written using the FITSIO package of ",&
       comline3 = "W.D. Pence"

  ! From original esas routines
  real(double), parameter :: dpi    =  3.1415926535897931d0 
  real(double), parameter :: d2pi   =  2.0d0*dpi
  real(double), parameter :: d4pi   =  4.0d0*dpi
  real(double), parameter :: dpid2  =  0.5d0*dpi
  real(double), parameter :: dpi180 =  dpi/180.0d0
  real(double), parameter :: d180pi =  180.0d0/dpi
  real(double), parameter :: Deg2Rad = d2pi/360.d0
  real(double), parameter :: Rad2Deg = 360.d0/d2pi
  !
  real(double), parameter :: AtomicMassUnit  = 1.6605389d-24   ! g
  !
  ! original had 6378.14 and Kip has .16???
  real(double), parameter :: EarthRadius = 6378.16 ! km ***check vs KK***
  ! JPLephem solar system constants 
  real(double), parameter :: daysec = 1.d0/8640
  real(double), parameter :: gauss = 0.01720209895d0
  real(double), parameter :: sunrad=2.315d0 
  real(double), parameter :: aultsc=499.004782d0 ! AU 'width' in light seconds
  real(double), parameter :: rschw=(gauss**2)*(aultsc**3)*(daysec**2)
  ! Earth time coordinate constants 
  real(double), parameter :: dyear =  36525.d0 ! *** why ??? *** 
  real(double), parameter :: djd1900 = 2415020.d0 ! JD=1900.01.01/00:00:00
  real(double), parameter :: djd1950 = 2433282.5d0 ! JD=1950.01.01/00:00:00
  real(double), parameter :: djd2000 = 2451545.d0 ! JD=2000.01.01/00:00:00
  real(double), parameter :: djd2050 = 2469807.5d0 ! JD=2050.01.01/00:00:00
  real(double), parameter :: dOb2000 = 0.40909280422D0 ! Obliquity of J2000
  
end module gofconstants_mod
